pub struct GpuMesh {
pub label: String,
pub ssbo_first_vertex: u32,
pub ssbo_first_index: u32,
pub use_ssbo: bool,
pub vertex_buffer: Option<Buffer>,
pub index_buffer: Option<Buffer>,
pub index_count: u32,
pub bounding_box: MeshBbox,
}Expand description
Represents a GPU mesh resource allocated from a CPU Mesh asset.
If the mesh was prepared with use_ssbo = true, the vertex and index data will be in the SSBO mesh buffer SsboMesh and the vertex_buffer and index_buffer fields will be None. Otherwhise, they will contain GPU buffers with the vertex and index data respectively.
Fields
label: Stringssbo_first_vertex: u32Offset to the vertex buffer in the SsboMesh if use_ssbo is true. 0 otherwise.
ssbo_first_index: u32Offset to the index buffer in the SsboMesh if use_ssbo is true. 0 otherwise.
use_ssbo: boolvertex_buffer: Option<Buffer>If not using SSBO, the GPU vertex buffer containing Vertex data. None if use_ssbo is true.
index_buffer: Option<Buffer>If not using SSBO, the GPU index buffer containing u32 index data. None if use_ssbo is true.
index_count: u32bounding_box: MeshBboxTrait Implementations
Sourceimpl RenderAsset for GpuMesh
impl RenderAsset for GpuMesh
type SourceAsset = Mesh
type Params = (Res<'static, RenderInstance>, ResMut<'static, SsboMeshDescriptor>, Res<'static, RenderAssets<GpuRenderData<SsboMesh>>>, Res<'static, RenderAssets<GpuBuffer>>)
Sourcefn prepare(
asset: Self::SourceAsset,
(render_instance, ssbo_descriptor, ssbo_mesh, gpu_buffers): &mut SystemParamItem<'_, '_, Self::Params>,
) -> Result<Self, PrepareAssetError<Self::SourceAsset>>
fn prepare( asset: Self::SourceAsset, (render_instance, ssbo_descriptor, ssbo_mesh, gpu_buffers): &mut SystemParamItem<'_, '_, Self::Params>, ) -> Result<Self, PrepareAssetError<Self::SourceAsset>>
Prepare the GPU asset from the CPU source [bevy::prelude::Asset] using the render-world system params.
fn label(&self) -> &str