GpuRenderBinding

Struct GpuRenderBinding 

pub struct GpuRenderBinding<T> {
    pub layout: BindGroupLayout,
    pub bind_group: BindGroup,
    /* private fields */
}
The gpu asset that is created from the render binding holder. This is the asset that is actually used in the render pass. It contains the bind group and bind group layout that are created according to the description in the RenderBinding implementation, and can be retrieved using the binding index specified in the description.

Fields

layout: BindGroupLayoutbind_group: BindGroup