pub struct GpuRenderData<R: RenderData> { /* private fields */ }Expand description
The gpu asset that is created from the render data holder. This is the asset that is actually used in the render pass.
It contains the gpu buffers and textures that are created according to the description in the RenderData implementation, and can be retrieved using the binding index specified in the description.
Implementations
Sourceimpl<R: RenderData> GpuRenderData<R>
impl<R: RenderData> GpuRenderData<R>
Sourcepub fn get_buffer(&self, binding: u32) -> Option<Handle<Buffer>>
pub fn get_buffer(&self, binding: u32) -> Option<Handle<Buffer>>
Retrieves the buffer handle for the given binding index.
Sourcepub fn get_texture(&self, binding: u32) -> Option<Handle<Texture>>
pub fn get_texture(&self, binding: u32) -> Option<Handle<Texture>>
Retrieves the texture handle for the given binding index.