Mesh

Struct Mesh 

pub struct Mesh {
    pub label: String,
    pub vertices: Vec<Vertex>,
    pub indices: Vec<u32>,
    pub bbox: MeshBbox,
    pub use_ssbo: bool,
}
Stores a CPU mesh with vertex and index data, along with metadata for GPU allocation. If loaded from a file, the mesh should have a .obj or .fbx extension. The vertices, indices, and bbox fields are expected to be populated by the asset loader; if not loaded from a file, they will default to empty and a degenerate bounding box respectively. This mesh will be uploaded to the GPU, represented by a GpuMesh asset.

Fields

label: Stringvertices: Vec<Vertex>indices: Vec<u32>bbox: MeshBboxuse_ssbo: bool

If true, the vertices and indices will automatically be placed in the SSBO mesh buffers SsboMesh for GPU access; if false, separate vertex and index buffers will be created with VERTEX and INDEX usage respectively. Defaults to true.