pub struct MeshLoaderSettings {
pub label: String,
pub use_ssbo: bool,
}Expand description
Settings for loading a mesh asset while creating a Mesh.
Fields
label: Stringuse_ssbo: boolShould the vertices and indices be in the SSBO mesh buffers? Defaults to true. If false, separate vertex and index buffers will be created.