RenderBindingBuilder

Struct RenderBindingBuilder 

pub struct RenderBindingBuilder { /* private fields */ }
A builder for the render binding. This is used in the description of the render binding to specify the buffers and textures that should be created on the gpu, and to build the bind group layout and bind group entries.

Implementations

Source

impl RenderBindingBuilder

pub fn add_buffer<R>( &mut self, render_data: &RenderAssets<GpuRenderData<R>>, render_data_idx: u32, ) -> &mut Self
where R: RenderData + Clone + Asset + 'static,

Adds a buffer to the render binding. The render_data parameter is the RenderData that contains the buffer, and the render_data_idx parameter is the index of the buffer in this render data.

pub fn add_buffer_from_id( &mut self, buffer: Option<AssetId<Buffer>>, ) -> &mut Self

Adds a buffer directly from an asset id.

pub fn add_texture_view<R>( &mut self, render_data: &RenderAssets<GpuRenderData<R>>, render_data_idx: u32, ) -> &mut Self
where R: RenderData + Clone + Asset + 'static,

Adds a texture view to the render binding. The render_data parameter is the RenderData that contains the texture, and the render_data_idx parameter is the index of the texture in this render data.

pub fn add_texture_view_from_id( &mut self, texture: Option<AssetId<Texture>>, ) -> &mut Self

Adds a texture view directly from an asset id.

pub fn add_texture_array_view<R>( &mut self, render_data: &RenderAssets<GpuRenderData<R>>, render_data_idx: u32, ) -> &mut Self
where R: RenderData + Clone + Asset + 'static,

Adds a texture array view to the render binding. The render_data parameter is the RenderData that contains the texture, and the render_data_idx parameter is the index of the texture in this render data.

pub fn add_texture_array_view_from_id( &mut self, texture: Option<AssetId<Texture>>, ) -> &mut Self

Adds a texture array view directly from an asset id.

pub fn add_texture_sampler<R>( &mut self, render_data: &RenderAssets<GpuRenderData<R>>, render_data_idx: u32, ) -> &mut Self
where R: RenderData + Clone + Asset + 'static,

Adds a texture sampler to the render binding. The render_data parameter is the RenderData that contains the texture, and the render_data_idx parameter is the index of the texture in this render data.

pub fn add_texture_sampler_from_id( &mut self, texture: Option<AssetId<Texture>>, ) -> &mut Self

Adds a texture sampler directly from an asset id.

pub fn add_storage_texture<R>( &mut self, render_data: &RenderAssets<GpuRenderData<R>>, render_data_idx: u32, ) -> &mut Self
where R: RenderData + Clone + Asset + 'static,

Adds a storage texture view to the render binding. The render_data parameter is the RenderData that contains the texture, and the render_data_idx parameter is the index of the texture in this render data.

pub fn add_storage_texture_from_id( &mut self, texture: Option<AssetId<Texture>>, ) -> &mut Self

Adds a storage texture view directly from an asset id.