pub struct RenderDataBuilder { /* private fields */ }Expand description
A builder for render data. This is used to describe the buffers and textures that should be created on the gpu for a render data.
After each data have been described, buffers and textures will be created on the gpu according to the description, and can be retrieved on the GPU side (see GpuRenderData).
Implementations
Sourceimpl RenderDataBuilder
impl RenderDataBuilder
Sourcepub fn add_buffer(&mut self, binding: u32, buffer: Buffer) -> &mut Self
pub fn add_buffer(&mut self, binding: u32, buffer: Buffer) -> &mut Self
Adds a buffer to the render data. The binding index is used to retrieve the buffer later when using this render data.
Sourcepub fn add_texture(&mut self, binding: u32, texture: Texture) -> &mut Self
pub fn add_texture(&mut self, binding: u32, texture: Texture) -> &mut Self
Adds a texture to the render data. The binding index is used to retrieve the texture later when using this render data.