pub struct Shader {
pub content: String,
}Expand description
Stores a shader source as UTF-8 text. File should have a .wgsl extension.
Most of the time, the user does not need to load shaders directly, as they can be embedded in materials and pipelines.
Note: the shader will only be compiled on the GPU when used in a pipeline, so this is just a container for the source code.
Fields
content: StringWGSL source contents as UTF-8 text.