Texture

Struct Texture 

pub struct Texture {
    pub label: String,
    pub size: (u32, u32),
    pub format: TextureFormat,
    pub usages: TextureUsages,
    pub sample_count: u32,
    pub layer_count: u32,
    pub mip_level_count: u32,
    pub data: Vec<u8>,
}
Stores a CPU texture with raw pixel data and metadata for GPU allocation. If loaded from a file, the texture should have a .png or .jpg extension. This texture will be uploaded to the GPU, represented by a GpuTexture asset.

Fields

label: Stringsize: (u32, u32)

Width and height in pixels of the CPU buffer.

format: TextureFormat

GPU texture format requested when allocating the resource. Defaults to Rgba8Unorm.

usages: TextureUsages

GPU usage flags (sampling, storage, copy, etc.). Defaults to TEXTURE_BINDING (sampled texture).

sample_count: u32

Sample count for the texture (1 for no MSAA, etc.). Defaults to 1.

layer_count: u32

Number of layers for array textures (1 for non-arrays, etc.). Defaults to 1.

mip_level_count: u32

Number of mip levels (1 = no mipmaps, 0 = auto-calculate max levels). Defaults to 1.

data: Vec<u8>

Raw pixel data for the texture, in the format specified by format. Defaults to empty.