BindingMut

Type Alias BindingMut 

pub type BindingMut<'w, T> = ResMut<'w, RenderAssets<GpuRenderBinding<T>>>;
The gpu asset that is created from the render binding holder. This is the asset that is actually used in the render pass.

Aliased Type

pub struct BindingMut<'w, T> { /* private fields */ }