pub struct GpuRenderBinding<T> {
pub layout: BindGroupLayout,
pub bind_group: BindGroup,
/* private fields */
}Expand description
The gpu asset that is created from the render binding holder. This is the asset that is actually used in the render pass.
It contains the bind group and bind group layout that are created according to the description in the RenderBinding implementation, and can be retrieved using the binding index specified in the description.
Fields
layout: BindGroupLayoutbind_group: BindGroupTrait Implementations
Sourceimpl<T> RenderAsset for GpuRenderBinding<T>
impl<T> RenderAsset for GpuRenderBinding<T>
type SourceAsset = T
type Params = (<T as RenderBinding>::Params, Res<'static, RenderInstance>, Res<'static, RenderAssets<GpuBuffer>>, Res<'static, RenderAssets<GpuTexture>>)
Sourcefn prepare(
asset: Self::SourceAsset,
(binding_params, render_instance, gpu_buffers, gpu_textures): &mut SystemParamItem<'_, '_, Self::Params>,
) -> Result<Self, PrepareAssetError<Self::SourceAsset>>
fn prepare( asset: Self::SourceAsset, (binding_params, render_instance, gpu_buffers, gpu_textures): &mut SystemParamItem<'_, '_, Self::Params>, ) -> Result<Self, PrepareAssetError<Self::SourceAsset>>
Prepare the GPU asset from the CPU source [bevy::prelude::Asset] using the render-world system params.
fn label(&self) -> &str