pub type SBinding<T> = SRes<RenderAssets<GpuRenderBinding<T>>>;Expand description
The gpu asset that is created from the render binding holder. This is the asset that is actually used in the render pass.
Aliased Type
pub struct SBinding<T> { /* private fields */ }