pub type SBindingMut<T> = SResMut<RenderAssets<GpuRenderBinding<T>>>;Expand description
The gpu asset that is created from the render binding holder. This is the asset that is actually used in the render pass.
Aliased Type
pub struct SBindingMut<T> { /* private fields */ }