pub type SRenderData<T> = SRes<RenderAssets<GpuRenderData<T>>>;Expand description
The gpu asset that is created from the render data holder. This is the asset that is actually used in the render pass.
Aliased Type
pub struct SRenderData<T> { /* private fields */ }