pub type SRenderDataMut<T> = SResMut<RenderAssets<GpuRenderData<T>>>;Expand description
The gpu asset that is created from the render data holder. This is the asset that is actually used in the render pass.
Aliased Type
pub struct SRenderDataMut<T> { /* private fields */ }